@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,7 +17,6 @@
  */
 package org.apache.hadoop.hbase.spark;
 
-import java.io.File;
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -48,12 +47,15 @@ import org.apache.hadoop.hbase.testclassification.MiscTests;
 import org.apache.hadoop.hbase.tool.LoadIncrementalHFiles;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.spark.SparkConf;
 import org.apache.spark.api.java.JavaRDD;
 import org.apache.spark.api.java.JavaSparkContext;
 import org.apache.spark.api.java.function.Function;
 import org.junit.After;
+import org.junit.AfterClass;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -61,77 +63,81 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import scala.Tuple2;
 
-import org.apache.hbase.thirdparty.com.google.common.io.Files;
-
-@Category({MiscTests.class, MediumTests.class})
+@Category({ MiscTests.class, MediumTests.class })
 public class TestJavaHBaseContext implements Serializable {
 
   @ClassRule
   public static final HBaseClassTestRule TIMEOUT =
-      HBaseClassTestRule.forClass(TestJavaHBaseContext.class);
+    HBaseClassTestRule.forClass(TestJavaHBaseContext.class);
 
-  private transient JavaSparkContext jsc;
-  HBaseTestingUtility htu;
-  protected static final Logger LOG = LoggerFactory.getLogger(TestJavaHBaseContext.class);
+  protected static transient JavaSparkContext JSC;
+  private static HBaseTestingUtility TEST_UTIL;
+  private static JavaHBaseContext HBASE_CONTEXT;
+  private static final Logger LOG = LoggerFactory.getLogger(TestJavaHBaseContext.class);
 
-
-
-  byte[] tableName = Bytes.toBytes("t1");
-  byte[] columnFamily = Bytes.toBytes("c");
+  protected byte[] tableName = Bytes.toBytes("t1");
+  protected byte[] columnFamily = Bytes.toBytes("c");
   byte[] columnFamily1 = Bytes.toBytes("d");
   String columnFamilyStr = Bytes.toString(columnFamily);
   String columnFamilyStr1 = Bytes.toString(columnFamily1);
 
+  @BeforeClass
+  public static void setUpBeforeClass() throws Exception {
+    // NOTE: We need to do this due to behaviour change in spark 3.2, where the below conf is true
+    // by default. We will get empty table as result (for small sized tables) for HBase version not
+    // having HBASE-26340
+    SparkConf sparkConf = new SparkConf().set("spark.hadoopRDD.ignoreEmptySplits", "false");
+    JSC = new JavaSparkContext("local", "JavaHBaseContextSuite", sparkConf);
+
+    init();
+  }
+
+  protected static void init() throws Exception {
+    TEST_UTIL = new HBaseTestingUtility();
+    Configuration conf = TEST_UTIL.getConfiguration();
+
+    HBASE_CONTEXT = new JavaHBaseContext(JSC, conf);
+
+    LOG.info("cleaning up test dir");
+
+    TEST_UTIL.cleanupTestDir();
+
+    LOG.info("starting minicluster");
+
+    TEST_UTIL.startMiniCluster();
+
+    LOG.info(" - minicluster started");
+  }
+
+  @AfterClass
+  public static void tearDownAfterClass() throws Exception {
+    LOG.info("shuting down minicluster");
+    TEST_UTIL.shutdownMiniCluster();
+    LOG.info(" - minicluster shut down");
+    TEST_UTIL.cleanupTestDir();
+
+    JSC.stop();
+    JSC = null;
+  }
 
   @Before
-  public void setUp() {
-    jsc = new JavaSparkContext("local", "JavaHBaseContextSuite");
+  public void setUp() throws Exception {
 
-    File tempDir = Files.createTempDir();
-    tempDir.deleteOnExit();
-
-    htu = new HBaseTestingUtility();
     try {
-      LOG.info("cleaning up test dir");
-
-      htu.cleanupTestDir();
-
-      LOG.info("starting minicluster");
-
-      htu.startMiniZKCluster();
-      htu.startMiniHBaseCluster(1, 1);
-
-      LOG.info(" - minicluster started");
-
-      try {
-        htu.deleteTable(TableName.valueOf(tableName));
-      } catch (Exception e) {
-        LOG.info(" - no table " + Bytes.toString(tableName) + " found");
-      }
-
-      LOG.info(" - creating table " + Bytes.toString(tableName));
-      htu.createTable(TableName.valueOf(tableName),
-          new byte[][]{columnFamily, columnFamily1});
-      LOG.info(" - created table");
-    } catch (Exception e1) {
-      throw new RuntimeException(e1);
+      TEST_UTIL.deleteTable(TableName.valueOf(tableName));
+    } catch (Exception e) {
+      LOG.info(" - no table {} found", Bytes.toString(tableName));
     }
+
+    LOG.info(" - creating table {}", Bytes.toString(tableName));
+    TEST_UTIL.createTable(TableName.valueOf(tableName),
+      new byte[][] { columnFamily, columnFamily1 });
+    LOG.info(" - created table");
   }
 
   @After
-  public void tearDown() {
-    try {
-      htu.deleteTable(TableName.valueOf(tableName));
-      LOG.info("shuting down minicluster");
-      htu.shutdownMiniHBaseCluster();
-      htu.shutdownMiniZKCluster();
-      LOG.info(" - minicluster shut down");
-      htu.cleanupTestDir();
-    } catch (Exception e) {
-      throw new RuntimeException(e);
-    }
-    jsc.stop();
-    jsc = null;
+  public void tearDown() throws Exception {
+    TEST_UTIL.deleteTable(TableName.valueOf(tableName));
   }
 
   @Test
@@ -144,11 +150,9 @@ public class TestJavaHBaseContext implements Serializable {
     list.add("4," + columnFamilyStr + ",a,4");
     list.add("5," + columnFamilyStr + ",a,5");
 
-    JavaRDD<String> rdd = jsc.parallelize(list);
+    JavaRDD<String> rdd = JSC.parallelize(list);
 
-    Configuration conf = htu.getConfiguration();
-
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
+    Configuration conf = TEST_UTIL.getConfiguration();
 
     Connection conn = ConnectionFactory.createConnection(conf);
     Table table = conn.getTable(TableName.valueOf(tableName));
@@ -163,9 +167,7 @@ public class TestJavaHBaseContext implements Serializable {
       table.close();
     }
 
-    hbaseContext.bulkPut(rdd,
-            TableName.valueOf(tableName),
-            new PutFunction());
+    HBASE_CONTEXT.bulkPut(rdd, TableName.valueOf(tableName), new PutFunction());
 
     table = conn.getTable(TableName.valueOf(tableName));
 
@@ -199,8 +201,7 @@ public class TestJavaHBaseContext implements Serializable {
       String[] cells = v.split(",");
       Put put = new Put(Bytes.toBytes(cells[0]));
 
-      put.addColumn(Bytes.toBytes(cells[1]), Bytes.toBytes(cells[2]),
-              Bytes.toBytes(cells[3]));
+      put.addColumn(Bytes.toBytes(cells[1]), Bytes.toBytes(cells[2]), Bytes.toBytes(cells[3]));
       return put;
     }
   }
@@ -212,23 +213,17 @@ public class TestJavaHBaseContext implements Serializable {
     list.add(Bytes.toBytes("2"));
     list.add(Bytes.toBytes("3"));
 
-    JavaRDD<byte[]> rdd = jsc.parallelize(list);
+    JavaRDD<byte[]> rdd = JSC.parallelize(list);
 
-    Configuration conf = htu.getConfiguration();
+    Configuration conf = TEST_UTIL.getConfiguration();
 
     populateTableWithMockData(conf, TableName.valueOf(tableName));
 
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
+    HBASE_CONTEXT.bulkDelete(rdd, TableName.valueOf(tableName),
+      new JavaHBaseBulkDeleteExample.DeleteFunction(), 2);
 
-    hbaseContext.bulkDelete(rdd, TableName.valueOf(tableName),
-            new JavaHBaseBulkDeleteExample.DeleteFunction(), 2);
-
-
-
-    try (
-            Connection conn = ConnectionFactory.createConnection(conf);
-            Table table = conn.getTable(TableName.valueOf(tableName))
-    ){
+    try (Connection conn = ConnectionFactory.createConnection(conf);
+      Table table = conn.getTable(TableName.valueOf(tableName))) {
       Result result1 = table.get(new Get(Bytes.toBytes("1")));
       Assert.assertNull("Row 1 should had been deleted", result1.getRow());
 
@@ -248,26 +243,23 @@ public class TestJavaHBaseContext implements Serializable {
 
   @Test
   public void testDistributedScan() throws IOException {
-    Configuration conf = htu.getConfiguration();
+    Configuration conf = TEST_UTIL.getConfiguration();
 
     populateTableWithMockData(conf, TableName.valueOf(tableName));
 
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
-
     Scan scan = new Scan();
     scan.setCaching(100);
 
     JavaRDD<String> javaRdd =
-            hbaseContext.hbaseRDD(TableName.valueOf(tableName), scan)
-                    .map(new ScanConvertFunction());
+      HBASE_CONTEXT.hbaseRDD(TableName.valueOf(tableName), scan).map(new ScanConvertFunction());
 
     List<String> results = javaRdd.collect();
 
     Assert.assertEquals(results.size(), 5);
   }
 
-  private static class ScanConvertFunction implements
-          Function<Tuple2<ImmutableBytesWritable, Result>, String> {
+  private static class ScanConvertFunction
+    implements Function<Tuple2<ImmutableBytesWritable, Result>, String> {
     @Override
     public String call(Tuple2<ImmutableBytesWritable, Result> v1) throws Exception {
       return Bytes.toString(v1._1().copyBytes());
@@ -283,18 +275,14 @@ public class TestJavaHBaseContext implements Serializable {
     list.add(Bytes.toBytes("4"));
     list.add(Bytes.toBytes("5"));
 
-    JavaRDD<byte[]> rdd = jsc.parallelize(list);
+    JavaRDD<byte[]> rdd = JSC.parallelize(list);
 
-    Configuration conf = htu.getConfiguration();
+    Configuration conf = TEST_UTIL.getConfiguration();
 
     populateTableWithMockData(conf, TableName.valueOf(tableName));
 
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
-
-    final JavaRDD<String> stringJavaRDD =
-            hbaseContext.bulkGet(TableName.valueOf(tableName), 2, rdd,
-            new GetFunction(),
-            new ResultFunction());
+    final JavaRDD<String> stringJavaRDD = HBASE_CONTEXT.bulkGet(TableName.valueOf(tableName), 2,
+      rdd, new GetFunction(), new ResultFunction());
 
     Assert.assertEquals(stringJavaRDD.count(), 5);
   }
@@ -302,39 +290,34 @@ public class TestJavaHBaseContext implements Serializable {
   @Test
   public void testBulkLoad() throws Exception {
 
-    Path output = htu.getDataTestDir("testBulkLoad");
+    Path output = TEST_UTIL.getDataTestDir("testBulkLoad");
     // Add cell as String: "row,falmily,qualifier,value"
-    List<String> list= new ArrayList<String>();
+    List<String> list = new ArrayList<String>();
     // row1
     list.add("1," + columnFamilyStr + ",b,1");
     // row3
     list.add("3," + columnFamilyStr + ",a,2");
     list.add("3," + columnFamilyStr + ",b,1");
     list.add("3," + columnFamilyStr1 + ",a,1");
-    //row2
+    // row2
     list.add("2," + columnFamilyStr + ",a,3");
     list.add("2," + columnFamilyStr + ",b,3");
 
-    JavaRDD<String> rdd = jsc.parallelize(list);
+    JavaRDD<String> rdd = JSC.parallelize(list);
 
-    Configuration conf = htu.getConfiguration();
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
+    Configuration conf = TEST_UTIL.getConfiguration();
 
-
-
-    hbaseContext.bulkLoad(rdd, TableName.valueOf(tableName), new BulkLoadFunction(),
-            output.toUri().getPath(), new HashMap<byte[], FamilyHFileWriteOptions>(), false,
-            HConstants.DEFAULT_MAX_FILE_SIZE);
+    HBASE_CONTEXT.bulkLoad(rdd, TableName.valueOf(tableName), new BulkLoadFunction(),
+      output.toUri().getPath(), new HashMap<byte[], FamilyHFileWriteOptions>(), false,
+      HConstants.DEFAULT_MAX_FILE_SIZE);
 
     try (Connection conn = ConnectionFactory.createConnection(conf);
-         Admin admin = conn.getAdmin()) {
+      Admin admin = conn.getAdmin()) {
       Table table = conn.getTable(TableName.valueOf(tableName));
       // Do bulk load
       LoadIncrementalHFiles load = new LoadIncrementalHFiles(conf);
       load.doBulkLoad(output, admin, table, conn.getRegionLocator(TableName.valueOf(tableName)));
 
-
-
       // Check row1
       List<Cell> cell1 = table.get(new Get(Bytes.toBytes("1"))).listCells();
       Assert.assertEquals(cell1.size(), 1);
@@ -369,10 +352,10 @@ public class TestJavaHBaseContext implements Serializable {
 
   @Test
   public void testBulkLoadThinRows() throws Exception {
-    Path output = htu.getDataTestDir("testBulkLoadThinRows");
+    Path output = TEST_UTIL.getDataTestDir("testBulkLoadThinRows");
     // because of the limitation of scala bulkLoadThinRows API
     // we need to provide data as <row, all cells in that row>
-    List<List<String>> list= new ArrayList<List<String>>();
+    List<List<String>> list = new ArrayList<List<String>>();
     // row1
     List<String> list1 = new ArrayList<String>();
     list1.add("1," + columnFamilyStr + ",b,1");
@@ -383,24 +366,22 @@ public class TestJavaHBaseContext implements Serializable {
     list3.add("3," + columnFamilyStr + ",b,1");
     list3.add("3," + columnFamilyStr1 + ",a,1");
     list.add(list3);
-    //row2
+    // row2
     List<String> list2 = new ArrayList<String>();
     list2.add("2," + columnFamilyStr + ",a,3");
     list2.add("2," + columnFamilyStr + ",b,3");
     list.add(list2);
 
-    JavaRDD<List<String>> rdd = jsc.parallelize(list);
+    JavaRDD<List<String>> rdd = JSC.parallelize(list);
 
-    Configuration conf = htu.getConfiguration();
-    JavaHBaseContext hbaseContext = new JavaHBaseContext(jsc, conf);
-
-    hbaseContext.bulkLoadThinRows(rdd, TableName.valueOf(tableName), new BulkLoadThinRowsFunction(),
-            output.toString(), new HashMap<byte[], FamilyHFileWriteOptions>(), false,
-            HConstants.DEFAULT_MAX_FILE_SIZE);
+    Configuration conf = TEST_UTIL.getConfiguration();
 
+    HBASE_CONTEXT.bulkLoadThinRows(rdd, TableName.valueOf(tableName),
+      new BulkLoadThinRowsFunction(), output.toString(), new HashMap<>(), false,
+      HConstants.DEFAULT_MAX_FILE_SIZE);
 
     try (Connection conn = ConnectionFactory.createConnection(conf);
-         Admin admin = conn.getAdmin()) {
+      Admin admin = conn.getAdmin()) {
       Table table = conn.getTable(TableName.valueOf(tableName));
       // Do bulk load
       LoadIncrementalHFiles load = new LoadIncrementalHFiles(conf);
@@ -438,27 +419,30 @@ public class TestJavaHBaseContext implements Serializable {
     }
 
   }
+
   public static class BulkLoadFunction
-          implements Function<String, Pair<KeyFamilyQualifier, byte[]>> {
-    @Override public Pair<KeyFamilyQualifier, byte[]> call(String v1) throws Exception {
+    implements Function<String, Pair<KeyFamilyQualifier, byte[]>> {
+    @Override
+    public Pair<KeyFamilyQualifier, byte[]> call(String v1) throws Exception {
       if (v1 == null) {
         return null;
       }
 
       String[] strs = v1.split(",");
-      if(strs.length != 4) {
+      if (strs.length != 4) {
         return null;
       }
 
       KeyFamilyQualifier kfq = new KeyFamilyQualifier(Bytes.toBytes(strs[0]),
-              Bytes.toBytes(strs[1]), Bytes.toBytes(strs[2]));
+        Bytes.toBytes(strs[1]), Bytes.toBytes(strs[2]));
       return new Pair(kfq, Bytes.toBytes(strs[3]));
     }
   }
 
   public static class BulkLoadThinRowsFunction
-          implements Function<List<String>, Pair<ByteArrayWrapper, FamiliesQualifiersValues>> {
-    @Override public Pair<ByteArrayWrapper, FamiliesQualifiersValues> call(List<String> list) {
+    implements Function<List<String>, Pair<ByteArrayWrapper, FamiliesQualifiersValues>> {
+    @Override
+    public Pair<ByteArrayWrapper, FamiliesQualifiersValues> call(List<String> list) {
       if (list == null) {
         return null;
       }
@@ -501,28 +485,21 @@ public class TestJavaHBaseContext implements Serializable {
         Cell cell = it.next();
         String q = Bytes.toString(CellUtil.cloneQualifier(cell));
         if ("counter".equals(q)) {
-          b.append("(")
-                  .append(q)
-                  .append(",")
-                  .append(Bytes.toLong(CellUtil.cloneValue(cell)))
-                  .append(")");
+          b.append("(").append(q).append(",").append(Bytes.toLong(CellUtil.cloneValue(cell)))
+            .append(")");
         } else {
-          b.append("(")
-                  .append(q)
-                  .append(",")
-                  .append(Bytes.toString(CellUtil.cloneValue(cell)))
-                  .append(")");
+          b.append("(").append(q).append(",").append(Bytes.toString(CellUtil.cloneValue(cell)))
+            .append(")");
         }
       }
       return b.toString();
     }
   }
 
-  private void populateTableWithMockData(Configuration conf, TableName tableName)
-          throws IOException {
-    try (
-      Connection conn = ConnectionFactory.createConnection(conf);
-      Table table = conn.getTable(tableName)) {
+  protected void populateTableWithMockData(Configuration conf, TableName tableName)
+    throws IOException {
+    try (Connection conn = ConnectionFactory.createConnection(conf);
+      Table table = conn.getTable(tableName); Admin admin = conn.getAdmin()) {
 
       List<Put> puts = new ArrayList<>(5);
 
@@ -532,7 +509,7 @@ public class TestJavaHBaseContext implements Serializable {
         puts.add(put);
       }
       table.put(puts);
+      admin.flush(tableName);
     }
   }
-
 }
