@@ -1,12 +1,13 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,18 +15,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.spark
 
 import java.util
-
 import org.apache.hadoop.hbase.spark.datasources.{HBaseSparkConf, JavaBytesEncoder}
 import org.apache.hadoop.hbase.util.Bytes
 import org.apache.spark.sql.types._
 import org.scalatest.{BeforeAndAfterAll, BeforeAndAfterEach, FunSuite}
 
-class DynamicLogicExpressionSuite  extends FunSuite with
-BeforeAndAfterEach with BeforeAndAfterAll with Logging {
+class DynamicLogicExpressionSuite
+    extends FunSuite
+    with BeforeAndAfterEach
+    with BeforeAndAfterAll
+    with Logging {
 
   val encoder = JavaBytesEncoder.create(HBaseSparkConf.DEFAULT_QUERY_ENCODER)
 
@@ -137,34 +139,31 @@ BeforeAndAfterEach with BeforeAndAfterAll with Logging {
     columnToCurrentRowValueMap.put("Col1", new ByteArrayComparable(Bytes.toBytes(10)))
     val valueFromQueryValueArray = new Array[Array[Byte]](1)
 
-    //great than
+    // great than
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 10)
     assert(!greaterLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 20)
     assert(!greaterLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //great than and equal
+    // great than and equal
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 5)
-    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap,
-      valueFromQueryValueArray))
+    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 10)
-    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap,
-      valueFromQueryValueArray))
+    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 20)
-    assert(!greaterAndEqualLogic.execute(columnToCurrentRowValueMap,
-      valueFromQueryValueArray))
+    assert(!greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //less than
+    // less than
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 10)
     assert(!lessLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 5)
     assert(!lessLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //less than and equal
+    // less than and equal
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 20)
     assert(lessAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
@@ -174,21 +173,21 @@ BeforeAndAfterEach with BeforeAndAfterAll with Logging {
     valueFromQueryValueArray(0) = encoder.encode(IntegerType, 10)
     assert(lessAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //equal too
+    // equal too
     valueFromQueryValueArray(0) = Bytes.toBytes(10)
     assert(equalLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = Bytes.toBytes(5)
     assert(!equalLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //not equal too
+    // not equal too
     valueFromQueryValueArray(0) = Bytes.toBytes(10)
     assert(!notEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
     valueFromQueryValueArray(0) = Bytes.toBytes(5)
     assert(notEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
-    //pass through
+    // pass through
     valueFromQueryValueArray(0) = Bytes.toBytes(10)
     assert(passThrough.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
 
@@ -196,7 +195,6 @@ BeforeAndAfterEach with BeforeAndAfterAll with Logging {
     assert(passThrough.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
   }
 
-
   test("Double Type") {
     val leftLogic = new LessThanLogicExpression("Col1", 0)
     leftLogic.setEncoder(encoder)
@@ -279,6 +277,71 @@ BeforeAndAfterEach with BeforeAndAfterAll with Logging {
     assert(!builtExpression.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
   }
 
+  test("Long Type") {
+    val greaterLogic = new GreaterThanLogicExpression("Col1", 0)
+    greaterLogic.setEncoder(encoder)
+    val greaterAndEqualLogic = new GreaterThanOrEqualLogicExpression("Col1", 0)
+    greaterAndEqualLogic.setEncoder(encoder)
+    val lessLogic = new LessThanLogicExpression("Col1", 0)
+    lessLogic.setEncoder(encoder)
+    val lessAndEqualLogic = new LessThanOrEqualLogicExpression("Col1", 0)
+    lessAndEqualLogic.setEncoder(encoder)
+    val equalLogic = new EqualLogicExpression("Col1", 0, false)
+    val notEqualLogic = new EqualLogicExpression("Col1", 0, true)
+
+    val columnToCurrentRowValueMap = new util.HashMap[String, ByteArrayComparable]()
+    columnToCurrentRowValueMap.put("Col1", new ByteArrayComparable(Bytes.toBytes(10L)))
+    val valueFromQueryValueArray = new Array[Array[Byte]](1)
+
+    // great than
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 10L)
+    assert(!greaterLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 20L)
+    assert(!greaterLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    // great than and equal
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 5L)
+    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 10L)
+    assert(greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 20L)
+    assert(!greaterAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    // less than
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 10L)
+    assert(!lessLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 5L)
+    assert(!lessLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    // less than and equal
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 20L)
+    assert(lessAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 20L)
+    assert(lessAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = encoder.encode(LongType, 10L)
+    assert(lessAndEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    // equal too
+    valueFromQueryValueArray(0) = Bytes.toBytes(10L)
+    assert(equalLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = Bytes.toBytes(5L)
+    assert(!equalLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    // not equal too
+    valueFromQueryValueArray(0) = Bytes.toBytes(10L)
+    assert(!notEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+
+    valueFromQueryValueArray(0) = Bytes.toBytes(5L)
+    assert(notEqualLogic.execute(columnToCurrentRowValueMap, valueFromQueryValueArray))
+  }
+
   test("String Type") {
     val leftLogic = new LessThanLogicExpression("Col1", 0)
     leftLogic.setEncoder(encoder)
